@@ -5,7 +5,7 @@ use utf8;
 package Amon2::Setup::Flavor::Basic;
 use parent qw(Amon2::Setup::Flavor);
 
-our $VERSION = '6.17';
+our $VERSION = '6.18';
 
 sub run {
     my $self = shift;
@@ -40,9 +40,8 @@ sub run {
         'DBD::SQLite'                     => '1.33',
         'Test::WWW::Mechanize::PSGI'      => 0,
         'Router::Boom'                    => '0.06',
-        'HTTP::Session2'                  => '1.03',
-        'Crypt::CBC'                      => '0',
-        'Crypt::Rijndael'                 => '0',
+        'Plack::Middleware::Session'      => 0,
+        'Plack::Session::Store::File'     => 0,
     });
 
     # static files
@@ -75,6 +74,9 @@ sub run {
     $self->render_file( 't/03_assets.t',      'Basic/t/03_assets.t', {
         psgi_file => $self->psgi_file,
     });
+    $self->render_file( 't/04_csrf.t',        'Basic/t/04_csrf.t', {
+        psgi_file => $self->psgi_file,
+    });
     $self->render_file( 'xt/01_pod.t',    'Minimum/xt/01_pod.t' );
     $self->render_file( 'xt/02_perlcritic.t', 'Basic/xt/02_perlcritic.t' );
 
